@@ -23,6 +23,8 @@ Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
 
     R}hvvgňȉ̂悤Ɏs
       perl     ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl55   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
+      perl56   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
       perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  on MSWin32
@@ -86,6 +88,9 @@ http://www.cpan.org/ports/index.html#jperl
 hѓóAɂ͌gѓdbɎ܂ŁAShiftJIS {ƂR[h
 LgĂ܂B̃\tgEFA͂ ShiftJIS 𒼐ڈ܂B̂
 UTF8 tO͂܂B
+̃\tgEFA Shift_JIS, Windows-31J, CP932, MacJapanese, SJIS(R90),
+Shift_JISX0213, Shift_JIS-2004 Ȃǂ ShiftJIS ̈Ƃł܂B
+̕ł͂̑̂ ShiftJIS Ƃŕ\Ă܂(u_vȂ)B
 
 Gȉ@͖蕡Gɂ܂B
 ȂGR[h̖肩GXP[v܂񂩁H
@@ -172,6 +177,9 @@ GXP[v_قȂ܂B
    make test
    make install
 
+   VXe strict.pm Ȃꍇ͕t strict.pm_  strict.pm Ƀl[
+   ĎgpĂB
+
 =head1 CXg[@(makegȂꍇ)
 
    perl pMakefile.pl         --- pMakefile.pl  pmake.bat 𐶐܂
@@ -179,22 +187,32 @@ GXP[v_قȂ܂B
    pmake.bat test
 
    pmake.bat install          --- ݎgp perl ɃCXg[܂
+   perl55   pmake.bat install --- perl5.005 ɃCXg[܂
+   perl56   pmake.bat install --- perl5.006 ɃCXg[܂
    perl58   pmake.bat install --- perl5.008 ɃCXg[܂
    perl510  pmake.bat install --- perl5.010 ɃCXg[܂
    perl512  pmake.bat install --- perl5.012 ɃCXg[܂
    perl64   pmake.bat install --- perl64    ɃCXg[܂
 
+   VXe strict.pm Ȃꍇ͕t strict.pm_  strict.pm Ƀl[
+   ĎgpĂB
+
    pmake.bat dist             --- CPAN zzppbP[W܂
    pmake.bat ptar.bat         --- ptar.bat 쐬܂
 
 =head1 \tgEFÄꗗ
 
-   Sjis.pm          --- ShiftJIS \[XR[htB^W[
-   Esjis.pm         --- Sjis.pm ̃^C[`
-   perl58.bat       --- ϐ PATH ̐ݒȂ perl5.8  TĎs
-   perl510.bat      --- ϐ PATH ̐ݒȂ perl5.10 TĎs
-   perl512.bat      --- ϐ PATH ̐ݒȂ perl5.12 TĎs
-   perl64.bat       --- ϐ PATH ̐ݒȂ perl64   TĎs
+   Sjis.pm               --- ShiftJIS \[XR[htB^W[
+   Esjis.pm              --- Sjis.pm ̃^C[`
+   perl55.bat            --- ϐ PATH ̐ݒȂ perl5.5  TĎs
+   perl56.bat            --- ϐ PATH ̐ݒȂ perl5.6  TĎs
+   perl58.bat            --- ϐ PATH ̐ݒȂ perl5.8  TĎs
+   perl510.bat           --- ϐ PATH ̐ݒȂ perl5.10 TĎs
+   perl512.bat           --- ϐ PATH ̐ݒȂ perl5.12 TĎs
+   perl64.bat            --- ϐ PATH ̐ݒȂ perl64   TĎs
+   strict.pm_            --- _~[ strict.pm
+   warnings.pm_          --- warnings.pm ̊ȈՔ
+   warnings/register.pm_ --- warnings/register.pm ̊ȈՔ
 
 =head1 GXP[vɂʌ݊̊m
 
@@ -373,7 +391,7 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   -S          Esjis::S
   -b          Esjis::b
   -c          Esjis::c
-  -t          Esjis::t
+  -t          -t
   -u          Esjis::u
   -g          Esjis::g
   -k          Esjis::k
@@ -785,8 +803,16 @@ oO񍐁Apb`}܂B
 
 =item * chdir
 
-    MSWin32  perl5.006, perl5.008, perl5.010, perl5.012 ɂĕR[h(0x5C)
-    ŏIpXƂł܂B
+    perl5.005 łΏ chdir() 𐳏Ɏsł܂B
+
+    perl5.006 ܂ perl5.00800 ̏ꍇŕR[h(0x5C)ŏIfBNg
+    w肵Ďsɂ jacode.pl CuKvłB
+
+    perl5.008001ȍ~, perl5.010, perl5.012 ɂĕR[h(0x5C)ŏIfB
+    Ngw肵ĎsƂAWin32 W[ Win32::GetShortPathName()
+    ɂĒZO擾łꍇ chdir() ܂BAchdir()
+    ̃JgfBNg Win32::GetShortPathName() ɂĎ擾Z
+    OɂȂ܂B
 
     QlN
     Bug #81839
@@ -1679,6 +1705,7 @@ vO~O񋟂܂B
  http://search.cpan.org/dist/Big5Plus/
  http://search.cpan.org/dist/EUCJP/
  http://search.cpan.org/dist/GB18030/
+ http://search.cpan.org/dist/GBK/
  http://search.cpan.org/dist/HP15/
  http://search.cpan.org/dist/INFORMIXV6ALS/
  http://search.cpan.org/dist/Latin1/
